@@ -29,11 +29,17 @@
 #include <libnautilus-private/nautilus-file.h>
 
 /* Returns NULL if there's no thumbnail yet. */
-char *     nautilus_get_thumbnail_uri               (NautilusFile *file);
-gboolean   nautilus_thumbnail_has_invalid_thumbnail (NautilusFile *file);
+void       nautilus_create_thumbnail                (NautilusFile *file);
+void       nautilus_thumbnail_frame_image           (GdkPixbuf **pixbuf);
 GdkPixbuf *nautilus_thumbnail_load_framed_image     (const char   *path);
 void       nautilus_update_thumbnail_file_renamed   (const char   *old_file_uri,
 						     const char   *new_file_uri);
 void       nautilus_remove_thumbnail_for_file       (const char   *old_file_uri);
 
+/* Queue handling: */
+void       nautilus_thumbnail_remove_from_queue     (const char   *file_uri);
+void       nautilus_thumbnail_remove_all_from_queue (void);
+void       nautilus_thumbnail_prioritize            (const char   *file_uri);
+
+
 #endif /* NAUTILUS_THUMBNAILS_H */
