@@ -38,15 +38,12 @@
 #include <libnautilus-private/nautilus-icon-container.h>
 #include <libnautilus-private/nautilus-link.h>
 #include <eel/eel-string-list.h>
-#include <libnautilus/nautilus-view.h>
+#include <libnautilus-private/nautilus-view.h>
+#include <libnautilus-private/nautilus-window-info.h>
 
 typedef struct FMDirectoryView FMDirectoryView;
 typedef struct FMDirectoryViewClass FMDirectoryViewClass;
 
-
-/* Bonobo command paths that are used by subclasses. Others are defined in fm-directory-view.c */
-#define FM_DIRECTORY_VIEW_COMMAND_RESET_BACKGROUND		"/commands/Reset Background"
-
 #define FM_TYPE_DIRECTORY_VIEW			(fm_directory_view_get_type ())
 #define FM_DIRECTORY_VIEW(obj)			(GTK_CHECK_CAST ((obj), FM_TYPE_DIRECTORY_VIEW, FMDirectoryView))
 #define FM_DIRECTORY_VIEW_CLASS(klass)		(GTK_CHECK_CLASS_CAST ((klass), FM_TYPE_DIRECTORY_VIEW, FMDirectoryViewClass))
@@ -138,6 +135,15 @@ struct FMDirectoryViewClass {
 	 */
 	GList *	(* get_selection) 	 	(FMDirectoryView *view);
 	
+	/* get_selection_for_file_transfer  is a function pointer for
+	 * subclasses to replace (override). Subclasses must replace it
+	 * with a function that returns a newly-allocated GList of
+	 * NautilusFile pointers. The difference from get_selection is
+	 * that any files in the selection that also has a parent folder
+	 * in the selection is not included.
+	 */
+	GList *	(* get_selection_for_file_transfer)(FMDirectoryView *view);
+	
         /* select_all is a function pointer that subclasses must override to
          * select all of the items in the view */
         void     (* select_all)	         	(FMDirectoryView *view);
@@ -162,9 +168,11 @@ struct FMDirectoryViewClass {
         /* zoom_to_level is a function pointer that subclasses must override
          * to set the zoom level of an object to the specified level. */
         void    (* zoom_to_level) 		(FMDirectoryView *view, 
-        				         gint 		 level);
+        				         NautilusZoomLevel level);
 
-        /* restore_default_zoom_level is a function pointer that subclasses must override
+        NautilusZoomLevel (* get_zoom_level)    (FMDirectoryView *view);
+
+	/* restore_default_zoom_level is a function pointer that subclasses must override
          * to restore the zoom level of an object to a default setting. */
         void    (* restore_default_zoom_level) (FMDirectoryView *view);
 
@@ -267,8 +275,12 @@ struct FMDirectoryViewClass {
 
 	gboolean (* can_rename_file)            (FMDirectoryView *view,
 						 NautilusFile *file);
+	/* select_all specifies whether the whole filename should be selected
+	 * or only its basename (i.e. everything except the extension)
+	 * */
 	void	 (* start_renaming_file)        (FMDirectoryView *view,
-					  	 NautilusFile *file);
+					  	 NautilusFile *file,
+						 gboolean select_all);
 
 	gboolean (* file_still_belongs)		(FMDirectoryView *view,
 						 NautilusFile	 *file);
@@ -284,15 +296,17 @@ struct FMDirectoryViewClass {
 	void	(* sort_directories_first_changed) (FMDirectoryView *view);
 
 	void	(* emblems_changed)                (FMDirectoryView *view);
+
+        /* Signals used only for keybindings */
+        gboolean (* trash)                         (FMDirectoryView *view);
+        gboolean (* delete)                        (FMDirectoryView *view);
 };
 
 /* GObject support */
 GType               fm_directory_view_get_type                         (void);
 
-/* Component embedding support */
-NautilusView *      fm_directory_view_get_nautilus_view                (FMDirectoryView  *view);
-
 /* Functions callable from the user interface and elsewhere. */
+NautilusWindowInfo *fm_directory_view_get_nautilus_window              (FMDirectoryView  *view);
 char *              fm_directory_view_get_uri                          (FMDirectoryView  *view);
 char *              fm_directory_view_get_backing_uri                  (FMDirectoryView  *view);
 gboolean            fm_directory_view_can_accept_item                  (NautilusFile     *target_item,
@@ -300,6 +314,7 @@ gboolean            fm_directory_view_can_accept_item                  (Nautilus
 									FMDirectoryView  *view);
 void                fm_directory_view_display_selection_info           (FMDirectoryView  *view);
 GList *             fm_directory_view_get_selection                    (FMDirectoryView  *view);
+GList *             fm_directory_view_get_selection_for_file_transfer  (FMDirectoryView  *view);
 void                fm_directory_view_stop                             (FMDirectoryView  *view);
 guint               fm_directory_view_get_item_count                   (FMDirectoryView  *view);
 gboolean            fm_directory_view_can_zoom_in                      (FMDirectoryView  *view);
@@ -308,9 +323,8 @@ GtkWidget *         fm_directory_view_get_background_widget            (FMDirect
 void                fm_directory_view_bump_zoom_level                  (FMDirectoryView  *view,
 									int               zoom_increment);
 void                fm_directory_view_zoom_to_level                    (FMDirectoryView  *view,
-									int               zoom_level);
-void                fm_directory_view_set_zoom_level                   (FMDirectoryView  *view,
-									int               zoom_level);
+									NautilusZoomLevel zoom_level);
+NautilusZoomLevel   fm_directory_view_get_zoom_level                   (FMDirectoryView  *view);
 void                fm_directory_view_restore_default_zoom_level       (FMDirectoryView  *view);
 void                fm_directory_view_reset_to_defaults                (FMDirectoryView  *view);
 void                fm_directory_view_select_all                       (FMDirectoryView  *view);
@@ -331,8 +345,6 @@ void                fm_directory_view_move_copy_items                  (const GL
 									int               x,
 									int               y,
 									FMDirectoryView  *view);
-gboolean            fm_directory_link_type_in_selection                (FMDirectoryView  *view,
-									NautilusLinkType  link_type);
 
 /* Wrappers for signal emitters. These are normally called 
  * only by FMDirectoryView itself. They have corresponding signals
@@ -347,8 +359,8 @@ void                fm_directory_view_end_loading                      (FMDirect
  */
 void                fm_directory_view_activate_files                   (FMDirectoryView  *view,
 									GList            *files,
-									Nautilus_ViewFrame_OpenMode mode,
-									Nautilus_ViewFrame_OpenFlags flags);
+									NautilusWindowOpenMode mode,
+									NautilusWindowOpenFlags flags);
 void                fm_directory_view_start_batching_selection_changes (FMDirectoryView  *view);
 void                fm_directory_view_stop_batching_selection_changes  (FMDirectoryView  *view);
 gboolean            fm_directory_view_confirm_multiple_windows         (FMDirectoryView  *view,
@@ -356,8 +368,7 @@ gboolean            fm_directory_view_confirm_multiple_windows         (FMDirect
 void                fm_directory_view_queue_file_change                (FMDirectoryView  *view,
 									NautilusFile     *file);
 void                fm_directory_view_notify_selection_changed         (FMDirectoryView  *view);
-Bonobo_UIContainer  fm_directory_view_get_bonobo_ui_container          (FMDirectoryView  *view);
-BonoboControl *     fm_directory_view_get_bonobo_control               (FMDirectoryView  *view);
+GtkUIManager *      fm_directory_view_get_ui_manager                   (FMDirectoryView  *view);
 EelStringList *     fm_directory_view_get_emblem_names_to_exclude      (FMDirectoryView  *view);
 NautilusDirectory  *fm_directory_view_get_model                        (FMDirectoryView  *view);
 GtkWindow	   *fm_directory_view_get_containing_window	       (FMDirectoryView  *view);
@@ -367,6 +378,8 @@ void                fm_directory_view_pop_up_background_context_menu   (FMDirect
 									GdkEventButton   *event);
 void                fm_directory_view_pop_up_selection_context_menu    (FMDirectoryView  *view,
 									GdkEventButton   *event); 
+void                fm_directory_view_pop_up_location_context_menu     (FMDirectoryView  *view,
+									GdkEventButton   *event); 
 void                fm_directory_view_send_selection_change            (FMDirectoryView *view);
 gboolean            fm_directory_view_should_show_file                 (FMDirectoryView  *view,
 									NautilusFile     *file);
@@ -376,5 +389,22 @@ void                fm_directory_view_new_folder                       (FMDirect
 void                fm_directory_view_new_file                         (FMDirectoryView  *view,
 									NautilusFile     *source);
 void                fm_directory_view_ignore_hidden_file_preferences   (FMDirectoryView  *view);
+void                fm_directory_view_init_view_iface                  (NautilusViewIface *iface);
+void                fm_directory_view_handle_url_drop                  (FMDirectoryView  *view,
+									const char       *encoded_url,
+									GdkDragAction     action,
+									int               x,
+									int               y);
+void                fm_directory_view_handle_uri_list_drop             (FMDirectoryView  *view,
+									const char       *item_uris,
+									GdkDragAction     action,
+									int               x,
+									int               y);
+void                fm_directory_view_freeze_updates                   (FMDirectoryView  *view);
+void                fm_directory_view_unfreeze_updates                 (FMDirectoryView  *view);
+void                fm_directory_view_add_subdirectory                (FMDirectoryView  *view,
+									NautilusDirectory*directory);
+void                fm_directory_view_remove_subdirectory             (FMDirectoryView  *view,
+									NautilusDirectory*directory);
 
 #endif /* FM_DIRECTORY_VIEW_H */
