@@ -94,7 +94,7 @@ static void nautilus_emblem_sidebar_iface_init        (NautilusSidebarIface
 static void sidebar_provider_iface_init               (NautilusSidebarProviderIface *iface);
 static GType nautilus_emblem_sidebar_provider_get_type (void);
 
-static GtkTargetEntry drag_types[] = {
+static const GtkTargetEntry drag_types[] = {
 	{"property/keyword", 0, 0 }
 };
 
@@ -104,7 +104,7 @@ enum {
 	TARGET_NETSCAPE_URL
 };
 
-static GtkTargetEntry dest_types[] = {
+static const GtkTargetEntry dest_types[] = {
 	{"text/uri-list", 0, TARGET_URI_LIST},
 	{"text/plain", 0, TARGET_URI},
 	{"_NETSCAPE_URL", 0, TARGET_NETSCAPE_URL}
@@ -462,8 +462,8 @@ create_emblem_widget (NautilusEmblemSidebar *emblem_sidebar,
 	GdkPixbuf *pixbuf;
 	
 	pixbuf = nautilus_icon_factory_get_pixbuf_from_name (name, NULL,
-					     NAUTILUS_ICON_SIZE_STANDARD,
-					     &display_name);
+							     NAUTILUS_ICON_SIZE_STANDARD, TRUE,
+							     &display_name);
 
 	keyword = nautilus_emblem_get_keyword_from_icon_name (name);
 	if (display_name == NULL) {
@@ -1045,6 +1045,12 @@ nautilus_emblem_sidebar_get_tab_label (NautilusSidebar *sidebar)
 	return g_strdup (_("Emblems"));
 }
 
+static char *
+nautilus_emblem_sidebar_get_tab_tooltip (NautilusSidebar *sidebar)
+{
+	return g_strdup (_("Show Emblems"));
+}
+
 static GdkPixbuf *
 nautilus_emblem_sidebar_get_tab_icon (NautilusSidebar *sidebar)
 {
@@ -1063,6 +1069,7 @@ nautilus_emblem_sidebar_iface_init (NautilusSidebarIface *iface)
 {
 	iface->get_sidebar_id = nautilus_emblem_sidebar_get_sidebar_id;
 	iface->get_tab_label = nautilus_emblem_sidebar_get_tab_label;
+	iface->get_tab_tooltip = nautilus_emblem_sidebar_get_tab_tooltip;
 	iface->get_tab_icon = nautilus_emblem_sidebar_get_tab_icon;
 	iface->is_visible_changed = nautilus_emblem_sidebar_is_visible_changed;
 }
